##
##
## All code copyright (c) 2013 UPC/UB
## All accompanying written materials copyright (c) 2013 UPC/UB
##
##
##   This program is free software: you can redistribute it and/or modify
##    it under the terms of the GNU General Public License as published by
##    the Free Software Foundation, either version 2 of the License, or
##    (at your option) any later version.
##
##    This program is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
##    You should have received a copy of the GNU General Public License
##    along with this program.  If not, see <http://www.gnu.org/licenses/>.
##
##########################################################################################################################################################
##########################################################################################################################################################

 
sigPeaksTable<-function(
		MAIT.object=NULL,
        printCSVfile=FALSE){
 

 
##########################################################################################################################################################
##       
##   sigPeaksTable is an output table build of some features of statistically significant variables. This table is build from a MAIT object.
##
########################################################################################################################################################## 


   if (is.null(MAIT.object)) {
        stop("No MAIT object was given")
    }


if(length(featureSigID(MAIT.object))==0){
          stop("No significant features found in the MAIT object. Make sure that functions peakAnnotation and spectralSigFeatures were launched")
        }

   
        peakList <- getPeaklist(MAIT.object)
   	peakList <- peakList[order(as.numeric(peakList$pcgroup)),]
        data <- scores(MAIT.object)
        index <- featureSigID(MAIT.object)
        classes <- classes(MAIT.object)
        classNum <- classNum(MAIT.object)
        resultsPath <- resultsPath(MAIT.object)
        Fisher <- LSDResults(MAIT.object)
        TTs <- pvalues(MAIT.object)

   

	sigPeaksTable <- matrix(nrow=1,ncol=ncol(peakList))
	colnames(sigPeaksTable) <- colnames(peakList)

        
	if (length(index)!=0){
          

           if (method(MAIT.object)!="None"){
             
              sigPeaksTable <- peakList[as.numeric(peakList$pcgroup)%in%index,]
             
           }else{
          
             sigPeaksTable <- peakList[as.numeric(peakList$pcgroup)%in%unique(as.numeric(peakList[index,]$pcgroup)),]
             
           }

           
           
	   p <- matrix(nrow=1,ncol=dim(sigPeaksTable)[1])
	   fisher <- matrix(nrow=1,ncol=dim(sigPeaksTable)[1])
           
           sigPeaksTable[,4:6] <- round(sigPeaksTable[,4:6]/60,2)
           
           
           
	   for(i in c(1:dim(sigPeaksTable)[1])){
          
              fisher[i] <- Fisher[as.numeric(sigPeaksTable[i,dim(sigPeaksTable)[2]])]
           
	   }
           
           p<-pvalues(MAIT.object)
           p <- p[as.numeric(peakList$pcgroup)%in%unique(as.numeric(peakList$pcgroup[index]))]

	   fisher <- as.vector(fisher)
	   fisherNames <- paste(classes[1],classes[2],sep="_")
           
	   for (i in c(3:length(classNum))){
          
	      fisherNames <- paste(fisherNames,classes[i],sep="_")
        
	   }
           
	   NamesFisher <- paste("Fisher",as.character(fisherNames),sep=" ")
	   names(fisher) <- NamesFisher
           
	   p <- matrix(p,ncol=1)
	   P.adjust <- p.adjust(p,"bonferroni")

           pAux <- matrix(ncol=1,nrow=dim(sigPeaksTable)[1])
           pAux.adjust <- matrix(ncol=1,nrow=dim(sigPeaksTable)[1])


           if (method(MAIT.object)!="None"){
             
           for (i in c(1:dim(sigPeaksTable)[1])){
             
           pAux[i,] <- p[which(index%in%as.numeric(sigPeaksTable$pcgroup)[i])]
           pAux.adjust[i,] <- P.adjust[which(index%in%as.numeric(sigPeaksTable$pcgroup)[i])]

           }

         }else{

           pAux <- p
           pAux.adjust <- P.adjust

         }

	   sigPeaksTable <- cbind(sigPeaksTable,pAux.adjust,pAux,fisher)

	   colnames(sigPeaksTable)[dim(sigPeaksTable)[2]-2] <- "P.adjust"
       	   colnames(sigPeaksTable)[dim(sigPeaksTable)[2]-1] <- "p"
	   colnames(sigPeaksTable)[dim(sigPeaksTable)[2]] <- NamesFisher
    


           

if(sum(is.na(MAIT.object@FeatureInfo@biotransformations))!=1&dim(MAIT.object@FeatureInfo@biotransformations)[1]!=0){

biotrans <- MAIT.object@FeatureInfo@biotransformations

for(i in c(1:dim(biotrans)[1])){
  if(peakList[as.numeric(biotrans[i,7]),]$adduct==""){

    sigPeaksTable[as.numeric(biotrans[i,7]),]$adduct <- biotrans[i,3]
    
  }else{
    
sigPeaksTable[as.numeric(biotrans[i,7]),]$adduct <- paste(sigPeaksTable[as.numeric(biotrans[i,7]),]$adduct,biotrans[i,3],sep=";")

}
}
}


                      if(printCSVfile==TRUE){

				if(!file.exists(paste(resultsPath,"Tables",sep="/"))){
					
					dir.create(paste(resultsPath,"Tables",sep="/"))

				}else{

					cat(" " ,fill=TRUE)
					cat(paste("Warning: Folder",paste(resultsPath,"Tables",sep="/"),"already exists. Possible file overwritting.",sep=" "),fill=TRUE)

				}


	           write.csv(x=sigPeaksTable,file=paste(resultsPath,"Tables/significantFeatures.csv",sep="/"),row.names=FALSE)

            }

           
       	}else{
             
           cat("WARNING: There are no significant features for this pvalue",fill=TRUE)
           
         }

   
 return(sigPeaksTable)
 }
 
