\name{spectralSigFeatures}
\alias{spectralSigFeatures}
\title{Extract significant features from a MAIT object}
\description{
Function spectralSigFeatures takes a \code{\link{MAIT-class}} object and obtains which of the variables are significant given a p-value threshold. The parameters of the significant features can ve printed to an output table (TRUE by default). Depending on the number of classes in the data, the function chooses between using ANOVA tests through function \link{spectralAnova}, or T-Student tests by using function \link{spectralTStudent}.
}
\usage{

spectralSigFeatures(pvalue = 0.05, 
                     bonferroni = FALSE, 
                     MAIT.object = NULL, 
                     printCSVfile = FALSE,
                     scale=FALSE)
}
\arguments{
  \item{MAIT.object}{
A \link{MAIT-class} object where function \link{peakAggregation} has already been applied. The output of the function is going to be an update of the same \link{MAIT-class} object.
}
  \item{pvalue}{
P-value threshold. Variables having a p-value lower than this value is considered as a significant variable.
}

  \item{bonferroni}{
Set to TRUE if the pvalue input parameter refers to a corrected bonferroni p-value.
}
  \item{printCSVfile}{
Set to TRUE if an output table has to be produced. See function \link{sigPeaksTable} for more information.
}
  \item{scale}{
Set to FALSE by default. When set to TRUE, a unit variance scaling of the data when no peak aggregation is performed. If a peak aggregation method is applied, this parameter is ignored.
}

}
\value{
  A \link{MAIT-class} object containing the significant features of the scores slot of \link{MAIT-class} object used as an input.
}
\seealso{
  \code{\link{MAIT-class}} \code{\link{spectralTStudent}} \code{\link{spectralAnova}} \code{\link{sigPeaksTable}}
}
\author{Francesc Fernandez,
 \email{francesc.fernandez.albert@upc.edu}}
\keyword{file}
